@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: netload.c,v 1.23 2003/10/19 16:55:39 carlos Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -57,6 +55,11 @@ static const unsigned long _glibtop_sysdeps_netload =
 (1L << GLIBTOP_NETLOAD_ERRORS_OUT) +
 (1L << GLIBTOP_NETLOAD_COLLISIONS);
 
+static const unsigned long _glibtop_sysdeps_netload_data =
+(1L << GLIBTOP_NETLOAD_ADDRESS) +
+(1L << GLIBTOP_NETLOAD_SUBNET) +
+(1L << GLIBTOP_NETLOAD_MTU);
+
 static const unsigned long _glibtop_sysdeps_netload_bytes =
 (1L << GLIBTOP_NETLOAD_BYTES_IN) +
 (1L << GLIBTOP_NETLOAD_BYTES_OUT) +
@@ -85,33 +88,98 @@ static const unsigned long _glibtop_sysdeps_netload_out =
 
 /* Init function. */
 
-int
+void
 glibtop_init_netload_s (glibtop *server)
 {
     server->sysdeps.netload = _glibtop_sysdeps_netload |
+	_glibtop_sysdeps_netload_data |
 	_glibtop_sysdeps_netload_bytes |
 	_glibtop_sysdeps_netload_packets;
-
-    return 0;
 }
 
 /* Provides network statistics. */
 
-int
+void
 glibtop_get_netload_s (glibtop *server, glibtop_netload *buf,
-		       const char *interface, unsigned transport,
-		       unsigned protocol)
+		       const char *interface)
 {
     char buffer [BUFSIZ], *p;
-    int have_bytes, fields;
+    int have_bytes, fields, skfd;
     FILE *f;
 
     memset (buf, 0, sizeof (glibtop_netload));
 
+    skfd = socket (AF_INET, SOCK_DGRAM, 0);
+    if (skfd) {
+	struct ifreq ifr;
+	unsigned flags;
+
+	strcpy (ifr.ifr_name, interface);
+	if (!ioctl (skfd, SIOCGIFFLAGS, &ifr)) {
+	    buf->flags |= (1L << GLIBTOP_NETLOAD_IF_FLAGS);
+	    flags = ifr.ifr_flags;
+	} else
+	    flags = 0;
+
+	if (flags & IFF_UP)
+	    buf->if_flags |= (1L << GLIBTOP_IF_FLAGS_UP);
+
+	if (flags & IFF_BROADCAST)
+	    buf->if_flags |= (1L << GLIBTOP_IF_FLAGS_BROADCAST);
+
+	if (flags & IFF_DEBUG)
+	    buf->if_flags |= (1L << GLIBTOP_IF_FLAGS_DEBUG);
+
+	if (flags & IFF_LOOPBACK)
+	    buf->if_flags |= (1L << GLIBTOP_IF_FLAGS_LOOPBACK);
+
+	if (flags & IFF_POINTOPOINT)
+	    buf->if_flags |= (1L << GLIBTOP_IF_FLAGS_POINTOPOINT);
+
+	if (flags & IFF_RUNNING)
+	    buf->if_flags |= (1L << GLIBTOP_IF_FLAGS_RUNNING);
+
+	if (flags & IFF_NOARP)
+	    buf->if_flags |= (1L << GLIBTOP_IF_FLAGS_NOARP);
+
+	if (flags & IFF_PROMISC)
+	    buf->if_flags |= (1L << GLIBTOP_IF_FLAGS_PROMISC);
+
+	if (flags & IFF_ALLMULTI)
+	    buf->if_flags |= (1L << GLIBTOP_IF_FLAGS_ALLMULTI);
+
+	if (flags & IFF_MULTICAST)
+	    buf->if_flags |= (1L << GLIBTOP_IF_FLAGS_MULTICAST);
+
+	strcpy (ifr.ifr_name, interface);
+	if (!ioctl (skfd, SIOCGIFADDR, &ifr)) {
+	    struct sockaddr_in addr =
+		*(struct sockaddr_in *) &ifr.ifr_addr;
+	    buf->address = addr.sin_addr.s_addr;
+	    buf->flags |= (1L << GLIBTOP_NETLOAD_ADDRESS);
+	}
+
+	strcpy (ifr.ifr_name, interface);
+	if (!ioctl (skfd, SIOCGIFNETMASK, &ifr)) {
+	    struct sockaddr_in addr =
+		*(struct sockaddr_in *) &ifr.ifr_addr;
+	    buf->subnet = addr.sin_addr.s_addr;
+	    buf->flags |= (1L << GLIBTOP_NETLOAD_SUBNET);
+	}
+
+	strcpy (ifr.ifr_name, interface);
+	if (!ioctl (skfd, SIOCGIFMTU, &ifr)) {
+	    buf->mtu = ifr.ifr_mtu;
+	    buf->flags |= (1L << GLIBTOP_NETLOAD_MTU);
+	}
+
+	close (skfd);
+    }
+
     /* Linux 2.1.114 - don't know where exactly this was added, but
-     * recent kernels have byte count in /proc/net/dev so we don't
-     * need IP accounting.
-     */
+	 * recent kernels have byte count in /proc/net/dev so we don't
+	 * need IP accounting.
+	 */
 
     if (server->os_version_code < 131442) {
 
@@ -185,34 +253,34 @@ glibtop_get_netload_s (glibtop *server, glibtop_netload *buf,
 
 	    fclose (f);
 
-	    if (success) return 0;
+	    if (success) return;
 	}
     }
 
     /* Ok, either IP accounting is not enabled in the kernel or
-     * it was not enabled for the requested interface. */
+	 * it was not enabled for the requested interface. */
 
     f = fopen ("/proc/net/dev", "r");
-    if (!f) return -1;
+    if (!f) return;
 
-    /* Skip over the header line. */
+	/* Skip over the header line. */
     fgets (buffer, BUFSIZ-1, f);
     fgets (buffer, BUFSIZ-1, f);
 
-    /* Starting with 2.1.xx (don't know exactly which version)
-     * /proc/net/dev contains both byte and package counters. */
+	/* Starting with 2.1.xx (don't know exactly which version)
+	 * /proc/net/dev contains both byte and package counters. */
 
     p = strchr (buffer, '|');
     if (!p) {
 	fclose (f);
-	return -1;
+	return;
     }
 
     /* Do we already have byte counters ? */
     have_bytes = strncmp (++p, "bytes", 5) == 0;
 
     /* Count remaining 'Receive' fields so we know where
-     * the first 'Transmit' field starts. */
+	 * the first 'Transmit' field starts. */
 	
     fields = 0;
     while (*p != '|') {
@@ -224,7 +292,7 @@ glibtop_get_netload_s (glibtop *server, glibtop_netload *buf,
     /* Should never happen. */
     if (fields < 2) {
 	fclose (f);
-	return -1;
+	return;
     }
     fields--;
 
@@ -283,6 +351,4 @@ glibtop_get_netload_s (glibtop *server, glibtop_netload *buf,
     }
 
     fclose (f);
-
-    return 0;
 }
