@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: procmap.c,v 1.7 2003/10/19 16:55:43 carlos Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -32,19 +30,17 @@ static const unsigned long _glibtop_sysdeps_proc_map = 0;
 
 /* Init function. */
 
-int
+void
 glibtop_init_proc_map_p (glibtop *server)
 {
-    server->sysdeps.proc_map = _glibtop_sysdeps_proc_map;
-
-    return 0;
+	server->sysdeps.proc_map = _glibtop_sysdeps_proc_map;
 }
 
 /* Provides detailed information about a process. */
 
 glibtop_map_entry *
-glibtop_get_proc_map_p (glibtop *server, glibtop_array *array, pid_t pid)
+glibtop_get_proc_map_p (glibtop *server, glibtop_proc_map *buf,	pid_t pid)
 {
-    memset (array, 0, sizeof (glibtop_array));
-    return NULL;
+	memset (buf, 0, sizeof (glibtop_proc_map));
+	return NULL;
 }
