@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: procargs.c,v 1.9 2003/10/19 16:55:51 carlos Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -32,19 +30,18 @@ static const unsigned long _glibtop_sysdeps_proc_args = 0;
 
 /* Init function. */
 
-int
+void
 glibtop_init_proc_args_p (glibtop *server)
 {
-    server->sysdeps.proc_args = _glibtop_sysdeps_proc_args;
-
-    return 0;
+	server->sysdeps.proc_args = _glibtop_sysdeps_proc_args;
 }
 
 /* Provides detailed information about a process. */
 
-char **
-glibtop_get_proc_args_p (glibtop *server, glibtop_array *array, pid_t pid)
+char *
+glibtop_get_proc_args_p (glibtop *server, glibtop_proc_args *buf,
+			 pid_t pid, unsigned max_len)
 {
-    memset (array, 0, sizeof (glibtop_array));
-    return NULL;
+	memset (buf, 0, sizeof (glibtop_proc_args));
+	return NULL;
 }
